==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/briefcase/brief_dialogs_nl.lua <==

dialogId("kd-uvod", "font_white", "Good morning, fish. This is an affair of the gravest importance and so we have chosen you, our ablest underwater agents.")
dialogStr("Goeie morgen, vissen. Dit is een zeer belangrijke zaak en daarom benaderen we jullie, onze beste onderwateragenten.")


dialogId("kd-ufo", "font_white", "Agents of FDTO - Fish Detective Training Organization - managed to get hold of several amateur snapshots of an extraterrestrial object which has crashed somewhere in your vicinity. Your mission, if you choose to accept it, will be to recover the UFO and acquire all the information you can about the principles and nature of interstellar propulsion.")
dialogStr("Agenten van de VDTO - VissenDetective Training Organisatie - zijn erin geslaagd om een aantal amateuropnamen te bemachtigen van een buitenaards object dat ergens bij jullie in de buurt is neergestort. Jullie missie, als jullie die accepteren, is om de vliegende schotel te bemachtigen en zoveel mogelijk informatie te vinden over de interstellaire aandrijving.")


dialogId("kd-mesto", "font_white", "You should also try to close some of our as yet unsolved cases. We are mostly interested in the circumstances surrounding the sinking of the mythical city, by chance in the same area.")
dialogStr("Het zou fijn zijn als jullie ook even kunnen kijken naar wat andere onopgeloste zaken. We zijn vooral geïnteresseerd in de omstandigheden omtrend het zinken van de legendarische stad, toevallig ook daar in de buurt.")


dialogId("kd-bermudy", "font_white", "This case may be connected to the mystery of the Bermuda Triangle. Find out why so many ships and planes have disappeared in this area over the past several decades.")
dialogStr("Deze zaak houdt wellicht verband met het mysterie van de Bermuda Driehoek. Achterhaal waarom er de afgelopen tientallen jaren zo veel schepen en vliegtuigen zijn verdwenen in deze omgeving.")


dialogId("kd-silver", "font_white", "One of the lost ships is rumored to have belonged to the legendary Captain Silver. There are still many uncertainties surrounding this famous pirate. Most of all we are interested in the map which shows the location of his buried treasure.")
dialogStr("Een van de verloren schepen zou het schip van de legendarische Kapitein Silver zijn geweest. Er is nogsteeds een hoop onduidelijkheid omtrend deze beruchte piraat. We zijn vooral geïnteresseerd in de kaart waar de verstopplaats van zijn schat op is aangegeven.")


dialogId("kd-pocitac", "font_white", "One of your most important tasks is to find the computer hidden in the deep by a certain criminal organization. It contains data about a project which could change the entire world.")
dialogStr("Een van jullie belangrijkste opdrachten is het vinden van de computer die door een bepaalde criminele organisatie in de diepte is verstopt. Er staat informatie op over een project dat de hele wereld zou kunnen veranderen.")


dialogId("kd-zelva", "font_white", "You should also find and detain the mysterious coral turtle. It escaped from the FDTO interrogation facility. It is not armed, but it supposedly has telepathic abilities.")
dialogStr("Jullie moeten ook de mysterieuze koraalschildpad zien te vinden en arresteren. Die is aan de VDTO ondervragingsafdeling ontsnapt. Hij is niet bewapend, maar is waarschijnlijk wel telepatisch.")


dialogId("kd-elektr", "font_white", "We have been notified that a certain nuclear power plant has been dumping its radioactive waste illegally. Check it out.")
dialogStr("We hebben bericht gekregen dat een bepaalde kernreactor illegaal radioactief afval heeft gedumpt. Zoek het uit.")


dialogId("kd-gral", "font_white", "And don`t forget to find the holy grail.")
dialogStr("En vergeet niet de Heilige Graal te vinden, als je toch bezig bent.")


dialogId("kd-zaver", "font_white", "And as usual: If anyone from your team is injured or killed, Altar will deny any knowledge of your existence and the level will be restarted.")
dialogStr("En, zoals altijd, als een van jullie team gewond raakt of omkomt, dan zal Altar ontkennen iets met jullie te maken te hebben en het veld zal worden herstart.")


dialogId("kd-znici", "font_white", "This disk will self-destruct in five seconds.")
dialogStr("Dit bericht zal zichzelf over vijf seconden vernietigen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/briefcase/brief_dialogs_nl.lua <==

dialogId("kd-uvod", "font_white", "Good morning, fish. This is an affair of the gravest importance and so we have chosen you, our ablest underwater agents.")
dialogStr("Goeie morgen, vissen. Dit is een zeer belangrijke zaak en daarom benaderen we jullie, onze beste onderwateragenten.")


dialogId("kd-ufo", "font_white", "Agents of FDTO - Fish Detective Training Organization - managed to get hold of several amateur snapshots of an extraterrestrial object which has crashed somewhere in your vicinity. Your mission, if you choose to accept it, will be to recover the UFO and acquire all the information you can about the principles and nature of interstellar propulsion.")
dialogStr("Agenten van de VDTO - VissenDetective Training Organisatie - zijn erin geslaagd om een aantal amateuropnamen te bemachtigen van een buitenaards object dat ergens bij jullie in de buurt is neergestort. Jullie missie, als jullie die accepteren, is om de vliegende schotel te bemachtigen en zoveel mogelijk informatie te vinden over de interstellaire aandrijving.")


dialogId("kd-mesto", "font_white", "You should also try to close some of our as yet unsolved cases. We are mostly interested in the circumstances surrounding the sinking of the mythical city, by chance in the same area.")
dialogStr("Het zou fijn zijn als jullie ook even kunnen kijken naar wat andere onopgeloste zaken. We zijn vooral geïnteresseerd in de omstandigheden omtrend het zinken van de legendarische stad, toevallig ook daar in de buurt.")


dialogId("kd-bermudy", "font_white", "This case may be connected to the mystery of the Bermuda Triangle. Find out why so many ships and planes have disappeared in this area over the past several decades.")
dialogStr("Deze zaak houdt wellicht verband met het mysterie van de Bermuda Driehoek. Achterhaal waarom er de afgelopen tientallen jaren zo veel schepen en vliegtuigen zijn verdwenen in deze omgeving.")


dialogId("kd-silver", "font_white", "One of the lost ships is rumored to have belonged to the legendary Captain Silver. There are still many uncertainties surrounding this famous pirate. Most of all we are interested in the map which shows the location of his buried treasure.")
dialogStr("Een van de verloren schepen zou het schip van de legendarische Kapitein Silver zijn geweest. Er is nogsteeds een hoop onduidelijkheid omtrend deze beruchte piraat. We zijn vooral geïnteresseerd in de kaart waar de verstopplaats van zijn schat op is aangegeven.")


dialogId("kd-pocitac", "font_white", "One of your most important tasks is to find the computer hidden in the deep by a certain criminal organization. It contains data about a project which could change the entire world.")
dialogStr("Een van jullie belangrijkste opdrachten is het vinden van de computer die door een bepaalde criminele organisatie in de diepte is verstopt. Er staat informatie op over een project dat de hele wereld zou kunnen veranderen.")


dialogId("kd-zelva", "font_white", "You should also find and detain the mysterious coral turtle. It escaped from the FDTO interrogation facility. It is not armed, but it supposedly has telepathic abilities.")
dialogStr("Jullie moeten ook de mysterieuze koraalschildpad zien te vinden en arresteren. Die is aan de VDTO ondervragingsafdeling ontsnapt. Hij is niet bewapend, maar is waarschijnlijk wel telepatisch.")


dialogId("kd-elektr", "font_white", "We have been notified that a certain nuclear power plant has been dumping its radioactive waste illegally. Check it out.")
dialogStr("We hebben bericht gekregen dat een bepaalde kernreactor illegaal radioactief afval heeft gedumpt. Zoek het uit.")


dialogId("kd-gral", "font_white", "And don’t forget to find the holy grail.")
dialogStr("En vergeet niet de Heilige Graal te vinden, als je toch bezig bent.")


dialogId("kd-zaver", "font_white", "And as usual: If anyone from your team is injured or killed, Altar will deny any knowledge of your existence and the level will be restarted.")
dialogStr("En, zoals altijd, als een van jullie team gewond raakt of omkomt, dan zal Altar ontkennen iets met jullie te maken te hebben en het veld zal worden herstart.")


dialogId("kd-znici", "font_white", "This disk will self-destruct in five seconds.")
dialogStr("Dit bericht zal zichzelf over vijf seconden vernietigen.")
